@@ -87,7 +87,7 @@ class PostForm(FlaskForm):
     loc1 = SelectField('Location', validate_choice=False)
     loc2 = SelectField(validate_choice=False)
     loc3 = SelectField(validate_choice=False)
-    postalcode = StringField('Postal Code', [InputRequired(), PostalCode()], default="N2J3Y6")
+    postalcode = StringField('Postal Code', [InputRequired(), PostalCode()])
     # TODO: Implement full address field
     #fulladdress = StringField('Full Address')
     phone = StringField('Phone', [PhoneNumber(), Optional()])
